#Analysis of Data Deposit Study Data
#Tess Grynoch

#load libraries
library(tidyverse)
library(scales)
library(grid)

#read data
data <- read.csv('Data/DataDepositStudy_DATA_2022-04-19_1212.csv')
colnames(data)[1] <- "pmid" 

#limit to umass chan authors with original or reused data 
#this limits responses to the first form
umass <- data %>% 
  filter(author_pos != 4) %>% 
  filter(orig_data == 1 | reuse_data == 1)


#calculate number and percent of articles that were NIH funded
sum(umass$fund___1) #307
sum(umass$fund___1)/nrow(umass)*100 #57.8%


#calculate number and percent of articles with a data availability statements
sum(umass$orig_data_pos___6) #92
sum(umass$orig_data_pos___6)/nrow(umass)*100 #17.2%

#calculate number of articles with original data only, reused data only, and both
umass %>% 
  select(pmid,orig_data, reuse_data) %>% 
  filter(orig_data == 1 & reuse_data == 0) %>% 
  nrow() #314 with original data only 

umass %>% 
  select(pmid,orig_data, reuse_data) %>% 
  filter(orig_data == 0 & reuse_data == 1) %>% 
  nrow() #174 with reused data only

umass %>% 
  select(pmid,orig_data, reuse_data) %>% 
  filter(orig_data == 1 & reuse_data == 1) %>% 
  nrow() #47 with both original and reused data

#calculate number and percent of articles with some data in a repository
repo <- data %>% 
  filter(orig_data_stor==1 | orig_data_stor_2 ==1) 
length(unique(repo$pmid)) #58
length(unique(repo$pmid))/nrow(umass)*100 #10.8%

#list of repositories used
repo2 <- repo %>% 
  select(pmid, orig_data_repo_2) %>% 
  setNames(c("pmid", "orig_data_repo"))

allrepo <- repo %>% 
  select(pmid, orig_data_repo) %>% 
  bind_rows(repo2) %>% 
  filter(orig_data_repo!="") %>% 
  separate_rows(orig_data_repo, sep = "; ")

distinctrepo <- allrepo %>% 
  distinct()

#write.csv(distinctrepo, "repository_list.csv")

#create chart of repositories used by number of articles
allrepo$orig_data_repo <- recode(allrepo$orig_data_repo, 
         "Genbank" = "GenBank",
         "Gene Expression Omnibus" = "Gene Expression Omnibus (GEO)",
         "Genome Expression Omnibus" = "Gene Expression Omnibus (GEO)", 
         "Genome Expression Omnibus (GEO)" = "Gene Expression Omnibus (GEO)",
         "Geo" = "Gene Expression Omnibus (GEO)", 
         "GEO" = "Gene Expression Omnibus (GEO)", 
         "Mass spectrometry Interactive Virtual Environment" = "Mass spectrometry Interactive Virtual Environment (MassIVE)",
         "MassIVE" = "Mass spectrometry Interactive Virtual Environment (MassIVE)", 
         "NCBI GEO: GSE129497" = "Gene Expression Omnibus (GEO)",
         "National Center for Biotechnology Information Sequence Read Archive" = "NCBI Sequence Read Archive", 
         "osteoarthritis initiative in NIHM Data Archive" = "NIMH Data Archive",
         "osteoarthritis initiative in NIMH Data Archive" = "NIMH Data Archive",
         "Protein DataBank" = "Protein Data Bank", 
         "EM Data Bank" = "Electron Microscopy Data Bank", 
         "Short Read Archive" = "NCBI Sequence Read Archive", 
         "NCBI Short Read Archive" = "NCBI Sequence Read Archive", 
         "immunoSEQ " = "immuneACCESS")
countrepo <- allrepo %>%
  distinct(pmid, orig_data_repo) %>% 
  count(orig_data_repo) %>% 
  dplyr::arrange(n, desc(orig_data_repo)) %>% 
  setNames(c("orig_data_repo", "articles"))

countrepo$orig_data_repo <- factor(countrepo$orig_data_repo, levels = countrepo$orig_data_repo)

repoplot <- ggplot(data = countrepo, mapping = aes(x=orig_data_repo, y=articles))+
  geom_bar(stat="identity", width = 0.4, position = position_dodge(width=0.5), fill="#000f9f")+
  scale_y_continuous(expand = c(0,0), limits = c(0,30))+
  coord_flip()+
  labs(title = "Repository", y= "Number of articles", x="")+
  theme_light()+
  theme(panel.grid.major.y = element_blank(), plot.title = element_text(hjust = -0.2, size=12,face="bold"), 
        axis.text=element_text(size=10), axis.title=element_text(size=12,face="bold"),
        plot.margin = unit(c(.2,.2,.2,.2), "in"))
repoplot

ggsave("Charts/Figure4.png", repoplot, width =10 , height =6.4, units = "in")


#create dataframe that summarizes funding
fund <- umass %>% 
  select(starts_with("fund___")) %>% 
  mutate_all(sum) %>% 
  slice(1) %>% 
  setNames(c("NIH", "NSF", "DOD", "VA", "AHRQ", "CDC", "CMS", "DHHS", "HRSA", "SAMHSA", "USAID", "None", "Other")) %>% 
  relocate("None", .after = last_col())

#checking to see if there are any other federal agencies in the other category
otherfund <- data %>% 
  distinct(fund_oth) %>% 
  select(fund_oth)
#write.csv(otherfund, "otherfund.csv")

#Combine US federal agencies except NIH and get count of distinct articles
fund <- umass %>% 
  select("pmid", starts_with("fund___")) %>% 
  select(!(fund___1|fund___12|fund___13)) 

fund <- filter(fund, rowSums(fund[ ,2:11]) != 0)

govfund <- umass %>% 
  select("pmid","fund_oth") %>% 
  separate_rows(fund_oth, sep = "; ") %>% 
  mutate(across(where(is.character), str_trim)) %>% 
  filter(fund_oth != "") %>% 
  filter(fund_oth == "Department of Education"|fund_oth == "Department of Energy"|fund_oth == "FDA"|fund_oth=="ORISE Research Participation Program at the Center for Drug Evaluation and Research")

GovFunders <- fund %>% 
  full_join(govfund, by ="pmid") %>% 
  select("pmid") %>% 
  n_distinct("pmid")

#Combine Non-US federal agencies
NonGovFunders <- umass %>% 
  select("pmid","fund_oth") %>% 
  separate_rows(fund_oth, sep = "; ") %>% 
  mutate(across(where(is.character), str_trim)) %>% 
  filter(fund_oth != "") %>% 
  filter(fund_oth != "Department of Education" & fund_oth != "Department of Energy" & fund_oth != "FDA"&fund_oth!="ORISE Research Participation Program at the Center for Drug Evaluation and Research") %>% 
  select("pmid") %>% 
  n_distinct("pmid")

#Sum articles funded by NIH
NIH <- umass %>% 
  select(fund___1) %>% 
  sum()

#Sum articles with no funding 
NoFund <- umass %>% 
  select(fund___13) %>% 
  sum()

#create table with values
funding <- data.frame(funder = c("NIH", "Other US Gov't Funders", "Other Funders", "No Funding"), 
           articles = c(NIH, GovFunders, NonGovFunders, NoFund))

#chart summarizing funding
funding$funder <- factor(funding$funder, levels = funding$funder)

fundplot <- ggplot(funding, aes(x=funder, y=articles)) +
  geom_bar(stat = "identity", fill="#000f9f") + 
  theme_light() +
  labs(x="Funder", y= "Number of articles") +
  theme(legend.position = "none", panel.grid.major.x = element_blank(),
        axis.text=element_text(size=10), axis.title=element_text(size=12,face="bold"))+
  scale_y_continuous(expand = c(0,0), limits = c(0,320))

fundplot

#ggsave("Charts/fundplot.png",fundplot, height=4, width = 6, units = "in" )

#summary of places to find information on the data 
datamention <- umass %>% 
  select(starts_with("orig_data_pos__")) %>% 
  mutate_all(sum) %>% 
  slice(1) %>% 
  setNames(c("Methods", "Acknowledgements", "Supplemental File", "References", "Notes", 
             "Data Availability Statement", "No Mention", "Other"))

datamention <- data.frame(ArticleLocation = colnames(datamention), articles = t(datamention), row.names = 1:8)

datamention <- datamention %>% 
  filter(ArticleLocation !="Other") %>% 
  dplyr::arrange(-articles) %>% 
  bind_rows(filter(datamention, ArticleLocation == "Other"))

datamention$ArticleLocation <- factor(datamention$ArticleLocation, levels = datamention$ArticleLocation)

mentionplot <- ggplot(datamention, mapping = aes(ArticleLocation, articles))+
  geom_bar(stat="identity", fill="#000f9f")+
  scale_x_discrete(guide = guide_axis(n.dodge = 2))+
  labs(x="Article location", y="Number of articles")+
  theme_light()+
  theme(legend.position = "none", panel.grid.major.x = element_blank(),
        axis.text=element_text(size=10), axis.title=element_text(size=12,face="bold"))+
  scale_y_continuous(expand = c(0,0), limits = c(0,275))

mentionplot

ggsave("Charts/Figure2.png",mentionplot, width = 12, height = 4, units = "in")

#Number of original datasets
origdata1 <- data %>% 
  select(pmid,orig_data) %>% 
  filter(orig_data == 1) %>% 
  nrow()

origdata2 <- data %>% 
  filter(redcap_repeat_instrument =="original_data_2") %>% 
  nrow()

TotalOrigData <- origdata1 + origdata2

#Analysis of where readers can access original data. Where is the data stored?
datastorage <- data %>%  
  select("orig_data_stor") %>%
  table() %>% 
  as.data.frame() %>%
  `colnames<-`(c("Location", "Number of datasets")) %>%
  mutate(Location = recode(Location, 
                           "1" = "Repository",
                           "2" = "Author website", 
                           "3" = "Journal website",
                           "4" = "Available upon request", 
                           "5" = "Other", 
                           "6" = "No mention"))
datastorage2 <- data %>%  
  select("orig_data_stor_2") %>%
  table() %>% 
  as.data.frame() %>%
  `colnames<-`(c("Location", "Number of datasets 2")) %>%
  mutate(Location = recode(Location, 
                           "1" = "Repository",
                           "2" = "Author website", 
                           "3" = "Journal website",
                           "4" = "Available upon request", 
                           "5" = "Other", 
                           "6" = "No mention")) 

#need to add no mention of storage location for articles that don't mention 
#data sharing at all 
#orig_data=1
#orig_data_pos___7 = 1

#get count of no storage mention from the first form
NoMention <- data %>% 
  filter(is.na(orig_data_stor)) %>% 
  filter(orig_data_pos___7 == 1) %>% 
  count(orig_data_pos___7) %>% 
  `colnames<-`(c("Location", "Number of datasets 3")) %>%
  mutate(Location = recode(Location, 
                           "1" = "No mention"))

#get count of no storage mention from the second form
NoMentionPMID <- data %>% 
  filter(orig_data_pos___7 == 1) %>% 
  filter(orig_data_count > 1) %>% 
  select("pmid") 

form2 <- data %>% 
  filter(redcap_repeat_instrument =="original_data_2") %>% 
  filter(is.na(orig_data_stor_2)) 

NoMentionForm2 <- semi_join(form2, NoMentionPMID, by = "pmid")

NoMention2 <- data.frame("Location" = "No mention", "NumberOfdatasets" = nrow(NoMentionForm2)) %>% 
  `colnames<-`(c("Location", "Number of datasets 4"))

#Check for observations that don't match (blanks in data storage)
#CheckPosition <- anti_join(form2, NoMentionPMID, by = "pmid")

#PMIDs that don't match -checked and these are articles that have "no match" 
# and another article location selected
#CheckOrigDataCount <- anti_join(NoMentionPMID, form2, by = "pmid")
#CheckOrigDataCount

#combine the 4 datastorage tables. datastorage2 has only 5 rows (no row for author website)
datastorage_total <- merge(datastorage, datastorage2, by="Location", all = TRUE)
datastorage_total <- merge(datastorage_total, NoMention, by="Location", all=TRUE)
datastorage_total <- merge(datastorage_total, NoMention2, by="Location", all=TRUE)

#create new column for total
datastorage_total <- datastorage_total %>% 
  mutate(Total = select(.,"Number of datasets", "Number of datasets 2", "Number of datasets 3", "Number of datasets 4") %>% 
           rowSums(na.rm = TRUE)) %>% 
  select(Location, Total)

#chart of where data is stored
datastored <- datastorage_total %>%
  select(Location, Total) %>% 
  filter(Location !="Other") %>% 
  dplyr::arrange(-Total) %>% 
  bind_rows(filter(datastorage_total, Location == "Other"))
  
datastored$Location <- factor(datastored$Location, levels = datastored$Location)


storageplot <- ggplot(datastored, mapping = aes(Location, Total))+
  geom_bar(stat="identity", fill="#69BADD")+
  labs(x="Data location", y="Number of datasets")+
  theme_light()+
  theme(legend.position = "none", panel.grid.major.x = element_blank(),
        axis.text=element_text(size=10), axis.title=element_text(size=12,face="bold"))+
  scale_y_continuous(expand = c(0,0), limits = c(0,1200))

storageplot

ggsave("Charts/Figure3.png",storageplot, width = 9.5, height = 3.17, units = "in")


#Analysis of data file format
dataformat1 <- data %>% 
  select("orig_data_format") %>% 
  table() %>% 
  as.data.frame() %>% 
  `colnames<-`(c("Format", "Number of datasets"))

dataformat2 <- data %>% 
  select("orig_data_format_2") %>% 
  table() %>% 
  as.data.frame()%>% 
  `colnames<-`(c("Format", "Number of datasets_2"))

dataformat3 <- full_join(dataformat1, dataformat2, by="Format")

dataformat3 <- dataformat3 %>% 
  mutate(Total = select(.,"Number of datasets", "Number of datasets_2") %>% 
           rowSums(na.rm = TRUE)) %>% 
  select(Format, Total)

#clean Formats listed
dataformat4 <- dataformat3 %>% 
  mutate(Format = recode(Format, 
                         ".xlsx" = "Excel",
                         "excel" = "Excel",
                         "Excel files" = "Excel",
                         "in article" = "In article",
                         "in manuscript" = "In article",
                         "In manuscript" = "In article",
                         "many options" = "Multiple",
                         "None - not actually in SRA" = "None",
                         "pdf" = "PDF",
                         "pdf - supplemental figure 13" = "PDF",
                         "Table on Word doc" = "Word document",
                         "text" = "TXT",
                         "txt" = "TXT",
                         "unknown" = "Unclear/Unknown",
                         "word document" = "Word document",
                         "csv" = "CSV",
                         "Image in Excel" = "Excel",
                         "xls" = "Excel",
                         "xlsx" = "Excel",
                         "multiple" = "Multiple", 
                         "mzTab; " = "mzTab",
                         "Table in Word doc" = "Word document", 
                         "Text" = "TXT",
                         "unknown - metadata not publicly avialable" = "Unclear/Unknown",
                         "unkown" = "Unclear/Unknown",
                         "TAR, TXT" = "TAR; TXT",
                         "bw" = "BW",
                         "Tar; TXT" = "TAR; TXT",
                         "Table in word doc" = "Word document",
                         "Unclear" = "Unclear/Unknown",
                         "Unknown" = "Unclear/Unknown",
                         "FASTQ, SRA" = "FASTQ; SRA")) %>% 
  group_by(Format) %>% 
  summarise(Total = sum(Total))

#Sum up the number of datasets that have multiple formats
dataformat4 %>% 
  filter(grepl(";",Format)) %>% 
  select(Total) %>% 
  sum()

#Breaking up the multiple formats into individual formats
#and clean and summarize formats
dataformat5 <- dataformat4 %>% 
  separate_rows(Format, sep = ";") %>% 
  filter(Format != "") %>% 
  mutate(Format = str_trim(Format)) %>% 
  mutate(Format = gsub("^\\.", "",Format)) %>% 
  mutate(Format = recode(Format, 
                         "xls" = "Excel",
                         "pdf" = "PDF",
                         "txt" = "TXT",
                         "csv" = "CSV"
                         )) %>% 
  group_by(Format) %>% 
  summarise(Total = sum(Total)) %>% 
  dplyr::arrange(-Total)


#write.csv(dataformat5, "Data/DataFormatList_v2.csv" ) # printing table

#Chart of data file formats

#collapse formats with 6 or less datasets into a format called other and 
#append it to the first ten rows of the dataset
#make Unclear/unknown the last row
OtherFormats <- dataformat5 %>% 
  filter(Total <= 6) 

dataformat6 <- dataformat5 %>% 
  slice(1:10) %>% 
  filter(Format != "Unclear/Unknown") %>% 
  add_row(Format = "Other", Total = sum(OtherFormats$Total)) %>% 
  bind_rows(filter(dataformat5, Format == "Unclear/Unknown"))
  
dataformat6$Format <- factor(dataformat6$Format, levels = dataformat6$Format)


formatplot <- ggplot(dataformat6, mapping = aes(Format, Total))+
  geom_bar(stat="identity", fill="#000f9f")+
  labs(x="Data format", y="Number of datasets")+
  theme_light()+
  theme(legend.position = "none", panel.grid.major.x = element_blank(),
        axis.text=element_text(size=10), axis.title=element_text(size=12,face="bold"))+
  scale_y_continuous(expand = c(0,0), limits = c(0,100))

#ggsave("Charts/formatplot.png",formatplot, width = 9.5, height = 3.17, units = "in")

#Analysis of license used
datalicense1 <- data %>% 
  select("orig_data_lic") %>% 
  table() %>% 
  as.data.frame() %>% 
  `colnames<-`(c("License", "Number of datasets"))

datalicense2 <- data %>% 
  select("orig_data_lic_2") %>% 
  table() %>% 
  as.data.frame()%>% 
  `colnames<-`(c("License", "Number of datasets_2"))

#combine the two datalicense tables
datalicense <- merge(datalicense1, datalicense2, by="License", all = TRUE)

#Create total column and spell out variables
datalicense <- datalicense %>% 
  mutate(Total = select(.,"Number of datasets", "Number of datasets_2") %>% 
           rowSums(na.rm = TRUE)) %>% 
  select(License, Total) %>% 
  mutate(License = recode(License, 
                           "1" = "CC-0",
                           "2" = "CC-BY", 
                           "3" = "Different Creative Commons License",
                           "4" = "Another License", 
                           "5" = "Can't Tell")) 

#table with count of other CC licenses
cclicense1 <- data %>% 
  select("orig_data_cc") %>% 
  table() %>% 
  as.data.frame() %>% 
  `colnames<-`(c("License", "Number of datasets"))

cclicense2 <- data %>% 
  select("orig_data_cc_2") %>% 
  table() %>% 
  as.data.frame() %>% 
  `colnames<-`(c("License", "Number of datasets_2"))

cclicense <- merge(cclicense1, cclicense2, by="License", all = TRUE)

cclicense <- cclicense %>% 
  mutate(Total = select(.,"Number of datasets", "Number of datasets_2") %>% 
           rowSums(na.rm = TRUE)) %>% 
  select(License, Total) %>% 
  mutate(License = recode(License, 
                          "2" = "CC-BY-NC"))

#add to the cclicense table to datalicense table 
#and remove "Different Creative Commons License" row
#reorder rows so other creative commons licenses are right after CC-BY

alldatalicense <- datalicense %>% 
  filter(License != "Different Creative Commons License") %>% 
  bind_rows(cclicense) %>% 
  filter(License != "Another License") %>% 
  filter(License != "Can't Tell") %>% 
  bind_rows(filter(datalicense, License == "Another License")) %>% 
  bind_rows(filter(datalicense, License == "Can't Tell"))

#finding original dataset rows without licenses
# check <- data %>%
#   select("pmid","orig_data_stor_2","orig_data_lic_2") %>%
#   filter(orig_data_stor_2 == "1" | orig_data_stor_2 == "2" | orig_data_stor_2 == "3" | orig_data_stor_2 == "5") %>%
#   filter(is.na(orig_data_lic_2))
# 
# write.csv(check, "data/checklicense.csv")

#Chart of licenses used
alldatalicense$License <- factor(alldatalicense$License, levels = alldatalicense$License)

licenseplot <- ggplot(alldatalicense, mapping = aes(License, Total))+
  geom_bar(stat="identity", fill="#000f9f")+
  scale_x_discrete(guide = guide_axis(n.dodge = 2))+
  labs(x="Data license", y="Number of datasets")+
  theme_light()+
  theme(legend.position = "none", panel.grid.major.x = element_blank(),
        axis.text=element_text(size=10), axis.title=element_text(size=12,face="bold"))+
  scale_y_continuous(expand = c(0,0), limits = c(0,120))

licenseplot

#ggsave("Charts/licenseplot.png",licenseplot, width = 12, height = 4, units = "in")

#Analysis of does dataset have an identifier
data_id1 <- data %>% 
  select("orig_data_doi") %>% 
  table() %>% 
  as.data.frame() %>% 
  `colnames<-`(c("Identifier", "Number of datasets"))

data_id2 <- data %>% 
  select("orig_data_doi_2") %>% 
  table() %>% 
  as.data.frame() %>% 
  `colnames<-`(c("Identifier", "Number of datasets_2"))

data_id3 <- merge(data_id1, data_id2, by="Identifier", all = TRUE)

data_id4 <- data_id3 %>% 
  mutate(Total = select(.,"Number of datasets", "Number of datasets_2") %>% 
           rowSums(na.rm = TRUE)) %>% 
  select(Identifier, Total) %>% 
  mutate(Identifier = recode(Identifier, 
                          "0" = "No",
                          "1" = "Yes")) 

#Pie Chart of identifiers

ggplot(data_id4, aes(x="", y=Total, fill=Identifier))+
  geom_bar(stat="identity", width=1) + 
  coord_polar("y", start=0)+
  theme_void()

#Analysis of reused data is the author's of someone else's
reuse_who <- data %>% 
  select("reuse_data_who") %>% 
  table() %>% 
  as.data.frame() %>% 
  `colnames<-`(c("Provenance", "Total")) %>% 
  mutate(Provenance = recode(Provenance, 
                             "1" = "An author",
                             "2" = "Someone else")) 

#Pie chart of reused data
ggplot(reuse_who, aes(x="", y=Total, fill=Provenance))+
  geom_bar(stat="identity", width=1) + 
  coord_polar("y", start=0)+
  theme_void()

#Where in the article does it mention where to find the reused data?
reusemention <- data %>% 
  filter(reuse_data == 1) %>% 
  select(starts_with("reuse_data_pos__")) %>% 
  mutate_all(sum) %>% 
  slice(1) %>% 
  setNames(c("Methods", "Acknowledgements", "Supplemental File", "References", "Notes", 
             "Data Availability Statement", "No Mention", "Other"))

reusemention <- data.frame(ArticleLocation = colnames(reusemention), articles = t(reusemention), row.names = 1:8)

reusemention <- reusemention %>% 
  filter(ArticleLocation !="Other") %>% 
  filter(articles > 0) %>% 
  dplyr::arrange(-articles) %>% 
  bind_rows(filter(reusemention, ArticleLocation == "Other"))

reusemention$ArticleLocation <- factor(reusemention$ArticleLocation, levels = reusemention$ArticleLocation)

reusementionplot <- ggplot(reusemention, mapping = aes(ArticleLocation, articles))+
  geom_bar(stat="identity", fill="#000f9f")+
  scale_x_discrete(guide = guide_axis(n.dodge = 2))+
  labs(x="Article location", y="Number of articles")+
  theme_light()+
  theme(legend.position = "none", panel.grid.major.x = element_blank(),
        axis.text=element_text(size=10), axis.title=element_text(size=12,face="bold"))+
  scale_y_continuous(expand = c(0,0), limits = c(0,175))

reusementionplot

ggsave("Charts/Figure5.png",reusementionplot, width = 12, height = 4, units = "in")

#List of data types
datatype1 <- data %>% 
  select("orig_data_type") %>% 
  table() %>% 
  as.data.frame() %>% 
  `colnames<-`(c("Type", "Number of datasets"))

datatype2 <- data %>% 
  select("orig_data_type_2") %>% 
  table() %>% 
  as.data.frame()%>% 
  `colnames<-`(c("Type", "Number of datasets_2"))

datatype3 <- full_join(datatype1, datatype2, by="Type")

datatype3 <- datatype3 %>% 
  mutate(Total = select(.,"Number of datasets", "Number of datasets_2") %>% 
           rowSums(na.rm = TRUE)) %>% 
  select(Type, Total)

#write.csv(datatype3,"Data/DataTypeList.csv")

#articles that share at least some portion of their original data are articles that 
#had a data availability statement, and the location of the data was not (no mention). 
#are these articles open access or not? 
#and the articles that did not share the data, are these articles open access or not? 

#open access articles that share at least some of their data
oasharepmid <- data %>% 
  select("pmid", "orig_data", "orig_data_stor","orig_data_stor_2", "oa_article") %>% 
  fill("pmid", "orig_data", "oa_article") %>% 
  filter(orig_data == 1 & oa_article == 1 & (orig_data_stor !=6 | orig_data_stor_2 !=6)) %>% 
  select("pmid") %>% 
  distinct() %>% 
  add_column(oa = "Yes") %>% 
  add_column(share = "Yes")

oashare <- n_distinct(oasharepmid$pmid) #83

#nooashare - non-open access articles that share at least some of their data
nooasharepmid <- data %>% 
  select("pmid", "orig_data", "orig_data_stor","orig_data_stor_2", "oa_article") %>% 
  fill("pmid", "orig_data", "oa_article") %>% 
  filter(orig_data == 1 & oa_article == 0 & (orig_data_stor !=6 | orig_data_stor_2 !=6)) %>% 
  select("pmid") %>% 
  distinct() %>% 
  add_column(oa = "No") %>% 
  add_column(share = "Yes")
  
nooashare <-  n_distinct(nooasharepmid$pmid) #41

#These are all the pmids that shared some data that should not appear in pmids that share no data at all
sharepmid <- data %>% 
  select("pmid", "orig_data", "orig_data_stor","orig_data_stor_2") %>% 
  fill("pmid", "orig_data") %>% 
  filter(orig_data == 1 & (orig_data_stor !=6 | orig_data_stor_2 !=6)) %>% 
  select("pmid") %>% 
  distinct() #124 rows

#oanoshare - open access articles that do not share at least some of their data
#all remaining articles that are open access that are not in the oashare list
oanosharepmid <- data %>% 
  select("pmid","orig_data", "oa_article") %>% 
  filter(orig_data == 1 & oa_article == 1) %>% 
  anti_join(sharepmid, by = "pmid") %>% 
  select("pmid") %>% 
  distinct() %>% 
  add_column(oa = "Yes") %>% 
  add_column(share = "No")

oanoshare <- n_distinct(oanosharepmid$pmid) #99

#nooanoshare - non-open access articles that do not share any of their data
#all remaining articles that are not open access that are not in the nooashare list
nooanosharepmid <- data %>% 
  select("pmid","orig_data", "oa_article") %>% 
  filter(orig_data == 1 & oa_article == 0) %>% 
  anti_join(sharepmid, by = "pmid") %>% 
  select("pmid") %>% 
  distinct() %>% 
  add_column(oa = "No") %>% 
  add_column(share = "No")
  
nooanoshare <- n_distinct(nooanosharepmid$pmid) #138

#create table with values for oa sharing
shareoa <- data.frame(sharing=c("Yes","Yes","No","No"), oa=c("Yes","No","Yes","No"), 
                      articles=c(oashare, nooashare, oanoshare, nooanoshare))

shareoa$sharing <- factor(shareoa$sharing, levels = c("Yes","No"))
shareoa$oa <- factor(shareoa$oa, levels = c("Yes","No"))

shareoaplot <- ggplot(shareoa, mapping = aes(x=sharing, y = articles, fill = oa))+
  geom_bar(stat="identity", position="dodge")+
  theme_light()+
  theme(panel.grid.major.x = element_blank(),
        axis.text=element_text(size=10), axis.title=element_text(size=12,face="bold"),
        legend.direction = "horizontal")+
  scale_y_continuous(expand = c(0,0), limits = c(0,175))+
  labs(x="Was data sharing mentioned in\nthe article?", y="Number of articles",
       fill="Was the article\npublished open access?")+
  guides(fill = guide_legend(title.position = "top",label.position = "bottom", label.vjust = -1))+
  scale_fill_manual(values= c("#F36F16","#5b5b5b"))

shareoaplot

#ggsave("Charts/shareoaplot.png", shareoaplot, width = 6, height = 4, units = "in")

#Chi squared test of whether articles that are published open access are 
#more likely to mention sharing their data
#create table for chi squared test. Start by combining all 4 pmid lists
chishareoa <- bind_rows(oasharepmid, nooasharepmid,oanosharepmid,nooanosharepmid)

chisq.test(table(chishareoa$oa, chishareoa$share))

#create table with comparison of articles that mentioned sharing data in 
#open access articles and non-open access articles
ggplot(chishareoa) +
  aes(x = oa, fill = share) +
  geom_bar(position = "fill") +
  labs(y="Proportion of articles that mention sharing their data", x="")+
  theme_light()+
  theme(panel.grid.major.x = element_blank(),
        axis.text=element_text(size=10), axis.title=element_text(size=12,face="bold"))+
  scale_y_continuous(expand = c(0,0), limits = c(0,1.1))+
  scale_fill_manual(values = c("#D2D1D0",  "#000f9f"))

#simpler bar chart with comparison of articles that mentioned sharing data in 
#open access articles and non-open access articles
shareoa2 <- data.frame(oa = c("Open Access","Non Open Access"), share = c(((oashare/(oashare+oanoshare))*100),((nooashare/(nooashare+nooanoshare))*100)))
shareoa2$oa <- factor(shareoa2$oa, levels = c("Open Access","Non Open Access"))

shareoaplot2 <- ggplot(shareoa2)+
  aes(x=oa, y= share)+
  geom_col(fill = "#000f9f")+
  labs(y="Percent of articles that mention \nsharing their data", x="")+
  theme_light()+
  theme(panel.grid.major.x = element_blank(),
        axis.text=element_text(size=10), axis.title=element_text(size=12,face="bold"))+
  scale_y_continuous(expand = c(0,0), limits = c(0,100))

ggsave("Charts/Figure6.png", shareoaplot2, width = 6, height = 4, units = "in")

